@@ -2,13 +2,20 @@ import os
 import sys
 
 py3 = sys.version_info.major >= 3
+py36 = sys.version_info[0:2] >= (3, 6)
 
 if py3:
     def isStringType(t):
         return isinstance(t, str)
 
-    def isPath(f):
-        return isinstance(f, (bytes, str))
+    if py36:
+        from pathlib import Path
+
+        def isPath(f):
+            return isinstance(f, (bytes, str, Path))
+    else:
+        def isPath(f):
+            return isinstance(f, (bytes, str))
 else:
     def isStringType(t):
         return isinstance(t, basestring)  # noqa: F821
